@@ -1,3 +1,10 @@
+test_that("ggplo2 rescaler", {
+  skip_if_not_installed("scales")
+  expect_type(mid_rescaler(mid = 5)(1:100), "double")
+  expect_length(mid_rescaler(mid = 5)(1:100), 100)
+  expect_equal(max(mid_rescaler(mid = 5)(1:100)), 1)
+})
+
 test_that("Palette colours", {
   palettes <- c("okabe ito", "bright", "contrast", "vibrant", "muted", "pale",
                 "dark", "light", "sunset", "BuRd", "PRGn", "YlOrBr",
